@@ -1,22 +1,18 @@
-#line 1
+#line 1 "inc/Module/Install/Fetch.pm - lib/Module/Install/Fetch.pm"
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Fetch.pm $ $Author: autrijus $
+# $Revision: #8 $ $Change: 1374 $ $DateTime: 2003/03/18 11:50:15 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Fetch;
+use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-use strict;
-use Module::Install::Base;
-
-use vars qw{$VERSION $ISCORE @ISA};
-BEGIN {
-	$VERSION = '0.66_02';
-	$ISCORE  = 1;
-	@ISA     = qw{Module::Install::Base};
-}
+$VERSION = '0.01';
 
 sub get_file {
     my ($self, %args) = @_;
     my ($scheme, $host, $path, $file) = 
         $args{url} =~ m|^(\w+)://([^/]+)(.+)/(.+)| or return;
 
-    if ( $scheme eq 'http' and ! eval { require LWP::Simple; 1 } ) {
+    if ($scheme eq 'http' and !eval { require LWP::Simple; 1 }) {
         $args{url} = $args{ftp_url}
             or (warn("LWP support unavailable!\n"), return);
         ($scheme, $host, $path, $file) = 
@@ -60,14 +56,14 @@ sub get_file {
             chdir $dir; return;
         }
 
-        my @dialog = split(/\n/, <<"END_FTP");
+        my @dialog = split(/\n/, << ".");
 open $host
 user anonymous anonymous\@example.com
 cd $path
 binary
 get $file $file
 quit
-END_FTP
+.
         foreach (@dialog) { $fh->print("$_\n") }
         $fh->close;
     } }
