@@ -1,6 +1,6 @@
 #line 1 "inc/Module/Install/Metadata.pm - lib/Module/Install/Metadata.pm"
 # $File: //depot/cpan/Module-Install/lib/Module/Install/Metadata.pm $ $Author: autrijus $
-# $Revision: #26 $ $Change: 1777 $ $DateTime: 2003/10/13 02:25:45 $ vim: expandtab shiftwidth=4
+# $Revision: #28 $ $Change: 1781 $ $DateTime: 2003/10/22 17:14:03 $ vim: expandtab shiftwidth=4
 
 package Module::Install::Metadata;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
@@ -12,14 +12,17 @@ use vars qw($VERSION);
 
 sub Meta { shift }
 
-my @scalar_keys = qw(name module_name version abstract author license distribution_type);
+my @scalar_keys = qw(
+    name module_name version abstract author license
+    distribution_type sign
+);
 my @tuple_keys  = qw(build_requires requires recommends bundles);
 
 foreach my $key (@scalar_keys) {
     *$key = sub {
         my $self = shift;
-        return $self->{values}{$key} unless @_;
-        $self->{values}{$key} = shift;
+        return $self->{'values'}{$key} unless @_;
+        $self->{'values'}{$key} = shift;
         return $self;
     };
 }
@@ -27,13 +30,13 @@ foreach my $key (@scalar_keys) {
 foreach my $key (@tuple_keys) {
     *$key = sub {
         my $self = shift;
-        return $self->{values}{$key} unless @_;
+        return $self->{'values'}{$key} unless @_;
         my @rv;
         while (@_) {
             my $module  = shift or last;
             my $version = shift || 0;
             my $rv = [$module, $version];
-            push @{$self->{values}{$key}}, $rv;
+            push @{$self->{'values'}{$key}}, $rv;
             push @rv, $rv;
         }
         return @rv;
@@ -44,18 +47,29 @@ sub features {
     my $self = shift;
     while (my ($name, $mods) = splice(@_, 0, 2)) {
         my $count = 0;
-        push @{$self->{values}{features}}, ($name => [
+        push @{$self->{'values'}{'features'}}, ($name => [
             map { (++$count % 2 and ref($_) and ($count += $#$_)) ? @$_ : $_ } @$mods
         ] );
     }
-    return @{$self->{values}{features}};
+    return @{$self->{'values'}{'features'}};
+}
+
+sub no_index {
+    my $self = shift;
+    my $type = shift;
+    push @{$self->{'values'}{'no_index'}{$type}}, @_ if $type;
+    return $self->{'values'}{'no_index'};
 }
 
 sub _dump {
     my $self = shift;
     my $package = ref($self->_top);
     my $version = $self->_top->VERSION;
-    my %values = %{$self->{values}};
+    my %values = %{$self->{'values'}};
+
+    delete $values{sign};
+
+    $values{license} ||= 'unknown';
     $values{distribution_type} ||= 'module';
     $values{name} ||= do {
         my $name = $values{module_name};
@@ -70,18 +84,31 @@ sub _dump {
     foreach my $key (@tuple_keys) {
         next unless exists $values{$key};
         $dump .= "$key:\n";
-        $dump .= "  $_->[0]: $_->[1]\n" for @{$values{$key}};
+        foreach (@{$values{$key}}) {
+            $dump .= "  $_->[0]: $_->[1]\n";
+        }
     }
 
-    return($dump . << "META");
+    if (my $no_index = $values{no_index}) {
+        push @{$no_index->{'directory'}}, 'inc';
+        require YAML;
+        local $YAML::UseHeader = 0;
+        $dump .= YAML::Dump({ no_index => $no_index});
+        $dump .= YAML::Dump({ private => $no_index});
+    }
+    else {
+        $dump .= << "META";
 no_index:
   directory:
     - inc
 private:
   directory:
     - inc
-generated_by: $package version $version
 META
+    }
+    
+    $dump .= "generated_by: $package version $version\n";
+    return $dump;
 }
 
 sub read {
