@@ -1,11 +1,11 @@
 #line 1 "inc/Module/Install/Win32.pm - lib/Module/Install/Win32.pm"
 # $File: //depot/cpan/Module-Install/lib/Module/Install/Win32.pm $ $Author: autrijus $
-# $Revision: #8 $ $Change: 1374 $ $DateTime: 2003/03/18 11:50:15 $ vim: expandtab shiftwidth=4
+# $Revision: #9 $ $Change: 1789 $ $DateTime: 2003/11/11 01:22:54 $ vim: expandtab shiftwidth=4
 
 package Module::Install::Win32;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use strict;
 
@@ -27,12 +27,12 @@ sub check_nmake {
 
     require File::Basename;
     my $rv = $self->get_file(
-        url         => 'http://download.microsoft.com/download/vc15/Patch/1.52/W95/EN-US/nmake15.exe',
-        ftp_url     => 'ftp://ftp.microsoft.com/Softlib/MSLFILES/nmake15.exe',
+        url         => 'http://download.microsoft.com/download/vc15/Patch/1.52/W95/EN-US/Nmake15.exe',
+        ftp_url     => 'ftp://ftp.microsoft.com/Softlib/MSLFILES/Nmake15.exe',
         local_dir   => File::Basename::dirname($^X),
         size        => 51928,
-        run         => 'nmake15.exe /o > nul',
-        check_for   => 'nmake.exe',
+        run         => 'Nmake15.exe /o > nul',
+        check_for   => 'Nmake.exe',
         remove      => 1,
     );
 
@@ -44,12 +44,13 @@ sub check_nmake {
 Since you are using Microsoft Windows, you will need the 'nmake' utility
 before installation. It's available at:
 
-  http://download.microsoft.com/download/vc15/Patch/1.52/W95/EN-US/nmake15.exe
-  ftp://ftp.microsoft.com/Softlib/MSLFILES/nmake15.exe
+  http://download.microsoft.com/download/vc15/Patch/1.52/W95/EN-US/Nmake15.exe
+      or
+  ftp://ftp.microsoft.com/Softlib/MSLFILES/Nmake15.exe
 
-Please download the file manually, save it to a directory in %PATH (e.g.
-C:\WINDOWS\COMMAND), then launch the MS-DOS command line shell, "cd" to
-that directory, and run "nmake15.exe" from there; that will create the
+Please download the file manually, save it to a directory in %PATH% (e.g.
+C:\WINDOWS\COMMAND\), then launch the MS-DOS command line shell, "cd" to
+that directory, and run "Nmake15.exe" from there; that will create the
 'nmake.exe' file needed by this module.
 
 You may then resume the installation process described in README.
