@@ -1,24 +1,21 @@
+# $File: //depot/cpan/Module-Install/lib/Module/Install/Bundle.pm $ $Author: autrijus $
+# $Revision: #5 $ $Change: 1805 $ $DateTime: 2003/12/11 18:43:02 $ vim: expandtab shiftwidth=4
+
 package Module::Install::Bundle;
+use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
 use strict;
-use Module::Install::Base;
 use Cwd ();
 use File::Find ();
 use File::Copy ();
 use File::Basename ();
 
-use vars qw{$VERSION $ISCORE @ISA};
-BEGIN {
-	$VERSION = '0.66_02';
-	$ISCORE  = 1;
-	@ISA     = qw{Module::Install::Base};
-}
-
 sub auto_bundle {
     my $self = shift;
 
     # Flatten array of arrays into a single array
-    my @core = map @$_, map @$_, grep ref, $self->requires;
+    my @core = map @$_, map @$_, grep ref,
+               $self->build_requires, $self->requires;
 
     $self->bundle(@core);
 }
@@ -33,16 +30,12 @@ sub bundle {
     $bundle_dir =~ s/\W+/\\W+/g;
 
     while (my ($name, $version) = splice(@_, 0, 2)) {
-        $version ||= 0;
-
-        my $source = $bundles->{$name} or die "Cannot find bundle source for $name";
-        my $target = File::Basename::basename($source);
-        $self->bundles($name, $target);
-
         next if eval "use $name $version; 1";
+        my $source = $bundles->{$name} or next;
+        my $target = File::Basename::basename($source);
         mkdir $target or die $! unless -d $target;
 
-        # XXX - clean those directories upon "make clean"?
+        # XXX - clean those directories upon "make clean"
         File::Find::find({
             wanted => sub {
                 my $out = $_;
@@ -52,6 +45,8 @@ sub bundle {
             },
             no_chdir => 1,
         }, $source);
+
+        $self->bundles($name, $target);
     }
 
     chdir $cwd;
@@ -72,34 +67,14 @@ sub read_bundles {
     return \%map;
 }
 
-
-sub auto_bundle_deps {
-    my $self = shift;
-
-    # Flatten array of arrays into a single array
-    my @core = map @$_, map @$_, grep ref, $self->requires;
-    while (my ($name, $version) = splice(@core, 0, 2)) {
-        next unless $name;
-         $self->bundle_deps($name, $version);
-         $self->bundle($name, $version);
-    }
-}
-
 sub bundle_deps {
-    my ($self, $pkg, $version) = @_;
-    my $deps = $self->admin->scan_dependencies($pkg) or return;
-
-    foreach my $key (sort keys %$deps) {
-        $self->bundle($key, ($key eq $pkg) ? $version : 0);
-    }
+    warn "bundle_deps() not yet implemented, sorry.\n";
 }
 
 1;
 
 __END__
 
-=pod
-
 =head1 NAME
 
 Module::Install::Bundle - Bundle distributions along with your distribution
@@ -109,24 +84,29 @@ Module::Install::Bundle - Bundle distributions along with your distribution
 Have your Makefile.PL read as follows:
 
   use inc::Module::Install;
-  
-  name      'Foo-Bar';
-  all_from  'lib/Foo/Bar.pm';
-  requires  'Baz' => '1.60';
-  
+
+  name("Foo-Bar");
+  version_from("lib/Foo/Bar.pm");
+  abstract("Description of your distribution");
+  author("Your Name <your@email.com>");
+  license("gpl"); # or "perl", etc
+  requires("Baz" => "1.60");
+  check_nmake();
+
   # one of either:
-  bundle    'Baz' => '1.60';
-  # OR:
-  auto_bundle;
-  
-  WriteAll;
+  auto_bundle(); # OR
+  bundle("Baz" => "1.60");
+
+  &Meta->write;
+  &Build->write if lc($0) eq "build.pl";
+  &Makefile->write if lc($0) eq "makefile.pl";
 
 =head1 DESCRIPTION
 
 Module::Install::Bundle allows you to bundle a CPAN distribution within your
 distribution. When your end-users install your distribution, the bundled
-distribution will be installed along with yours, unless a newer version of
-the bundled distribution already exists on their local filesystem.
+distribution will be installed along with yours, unless a newer version of the
+bundled distribution already exists on their local filesystem.
 
 While bundling will increase the size of your distribution, it has several
 benefits:
@@ -144,52 +124,49 @@ to be installed will be acquired from CPAN and then installed.
 
 =over 4
 
-=item * auto_bundle()
+=item * L<auto_bundle>
 
-Takes no arguments, will bundle every distribution specified by a C<requires()>.
-When you, as a module author, do a C<perl Makefile.PL> the latest versions of
-the distributions to be bundled will be acquired from CPAN and placed in
-F<inc/BUNDLES/>.
+Takes no arguments, will bundle every distribution specified by a requires().
+When you, as a module author, do a perl Makefile.PL the latest versions of the
+distributions to be bundled will be acquired from CPAN and placed in
+inc/BUNDLES/.
 
-=item * bundle($name, $version)
+=item * L<bundle>
 
 Takes a list of key/value pairs specifying a distribution name and version
 number. When you, as a module author, do a perl Makefile.PL the distributions
-that you specified with C<bundle()> will be acquired from CPAN and placed in
-F<inc/BUNDLES/>.
-
-=item * bundle_deps($name, $version)
-
-Same as C<bundle>, except that all dependencies of the bundled modules are
-also detected and bundled.  To use this function, you need to declare the
-minimum supported perl version first, like this:
-
-    requires( perl => 5.005 );
-
-=item * auto_bundle_deps
-
-Same as C<auto_bundle>, except that all dependencies of the bundled
-modules are also detected and bundled. This function has the same constraints as bundle_deps.
+that you specified with bundle() will be acquired from CPAN and placed in
+inc/BUNDLES/.
 
 =back
 
 =head1 BUGS
 
-Please report any bugs to (patches welcome):
-
-    http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Module-Install
-
-=head1 AUTHORS
-
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
-
-Documentation by Adam Foxson E<lt>afoxson@pobox.comE<gt>
+  Please report any bugs to (patches welcome):
+  http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Module-Install
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004, 2005 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
+  Copyright 2003 by Autrijus Tang <autrijus@autrijus.org>.
+
+=head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<perl>
+
+=item * L<ExtUtils::AutoInstall>
+
+=back
+
+=head1 AUTHORS
+
+  Autrijus Tang <autrijus@autrijus.org>
+  Documentation by Adam Foxson <afoxson@pobox.com>
+
 =cut
